@@ -49,6 +49,8 @@ struct _DriveList
     GtkWidget *dummy;
     gint count;
 
+    GSettings *settings;
+
     int icon_size;
 };
 
@@ -65,7 +67,6 @@ void       drive_list_set_panel_size  (DriveList *list,
 				       int panel_size);
 void       drive_list_set_transparent (DriveList *self,
 				       gboolean transparent);
-extern GSettings *settings;
 void       drive_list_redraw (DriveList *self);
 void       settings_color_changed (GSettings *settings, gchar *key, DriveList *drive_list);
 
