@@ -22,7 +22,6 @@
 
 #include <glib/gi18n.h>
 #include <gdk/gdk.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 #include <mate-panel-applet.h>
@@ -30,7 +29,6 @@
 
 #define STICKYNOTES_SCHEMA	"org.mate.stickynotes"
 #define BUILDER_PATH	GTK_BUILDERDIR "/stickynotes.ui"
-#define ICON_PATH	STICKYNOTES_ICONDIR
 
 #define STICKYNOTES_STOCK_LOCKED	"stickynotes-stock-locked"
 #define STICKYNOTES_STOCK_UNLOCKED	"stickynotes-stock-unlocked"
@@ -58,8 +56,8 @@ typedef struct
 	GList *notes;			/* Linked-List of all the sticky notes */
 	GList *applets;			/* Linked-List of all the applets */
 	
-	GdkPixbuf *icon_normal;		/* Normal applet icon */
-	GdkPixbuf *icon_prelight;	/* Prelighted applet icon */
+	cairo_surface_t *icon_normal;	/* Normal applet icon */
+	cairo_surface_t *icon_prelight;	/* Prelighted applet icon */
 
 	GSettings *settings;		/* Shared GSettings */
 
@@ -69,14 +67,6 @@ typedef struct
     gboolean visible;       /* Toggle show/hide notes */
 } StickyNotes;
 
-/* Sticky Notes Icons */
-typedef struct
-{
-	gchar *stock_id;
-	gchar *filename;
-
-} StickyNotesStockIcon;
-
 /* Sticky Notes Applet */
 typedef struct
 {
@@ -86,7 +76,6 @@ typedef struct
 	GtkWidget *destroy_all_dialog;	/* The applet it's destroy all dialog */
 	
 	gboolean prelighted;		/* Whether applet is prelighted */
-	gboolean pressed;		/* Whether applet is pressed */
 
 	gint panel_size;
 	MatePanelAppletOrient panel_orient;
@@ -106,7 +95,6 @@ typedef enum
 extern StickyNotes *stickynotes;
 
 void stickynotes_applet_init(MatePanelApplet *mate_panel_applet);
-void stickynotes_applet_init_icons(void);
 void stickynotes_applet_init_prefs(void);
 
 StickyNotesApplet * stickynotes_applet_new(MatePanelApplet *mate_panel_applet);
